@@ -1,21 +1,23 @@
-from peewee import AutoField, CharField, IntegerField, BooleanField
+from peewee import AutoField, CharField, IntegerField, BooleanField, FloatField, DateTimeField
 from peewee import SQL
 from ..base import BaseModel
 
 MAG_ECO_TYPE_LIST = [
     ('T', 'Cutting'),  # Tampon
     ('C', 'Picking'),  # Cueillette
-    ('R', 'Return'),   # Retour
-    ('A', 'Astus'),    # Astus
-    ('L', 'Riedl'),    # Riedl (GPI)
+    ('R', 'Return'),  # Retour
+    ('A', 'Astus'),  # Astus
+    ('L', 'Riedl'),  # Riedl (GPI)
+    ('E', 'External')  # External (Shelf, cabinet)
 ]
 
 MAG_ECO_TYPE = [m[0] for m in MAG_ECO_TYPE_LIST]
 
 
 class Magasin(BaseModel):
-
     pk = AutoField(column_name="x_pk", primary_key=True)
+    last_reap = DateTimeField(
+        column_name='x_last_reap', null=True, constraints=[SQL("DEFAULT '0000-00-00 00:00:00'")])
     mag = CharField(
         column_name='x_mag', unique=True, null=True, max_length=3, constraints=[SQL("DEFAULT ''")])
     type_mag = CharField(
@@ -93,6 +95,10 @@ class Magasin(BaseModel):
         column_name='x_split_liste', null=True, constraints=[SQL("DEFAULT 0")])
     libelle = CharField(
         column_name='x_libelle', max_length=35, constraints=[SQL("DEFAULT ''")], default='')
+    type_machine = CharField(
+        column_name="x_type_machine", max_length=20, constraints=[SQL("DEFAULT ''")], default='')
+    avatar = CharField(
+        column_name='x_avatar', default='', max_length=50)
 
     class Meta:
         table_name = "f_mag"
@@ -110,7 +116,6 @@ class Magasin(BaseModel):
 
 
 class Espace(BaseModel):
-
     pk = AutoField(
         column_name='x_pk', primary_key=True)
     poste = CharField(
@@ -143,18 +148,28 @@ class Espace(BaseModel):
 
 
 class Adresse(BaseModel):
-
     pk = AutoField(column_name="x_pk", primary_key=True)
     adresse = CharField(
-        column_name="x_adr", null=True, constraints=[SQL("DEFAULT ''")]
+        column_name="x_adr", max_length=19,
+        null=True, constraints=[SQL("DEFAULT ''")]
+    )
+    etat = CharField(
+        column_name="x_etat", max_length=1,
+        null=True, constraints=[SQL("DEFAULT ''")]
     )
-    etat = CharField(column_name="x_etat", null=True, constraints=[SQL("DEFAULT ''")])
     format = CharField(
-        column_name="x_format", null=True, constraints=[SQL("DEFAULT ''")]
+        column_name="x_format", max_length=10,
+        null=True, constraints=[SQL("DEFAULT ''")]
     )
-    magasin = CharField(column_name="x_mag", null=True, constraints=[SQL("DEFAULT ''")])
-    contenant = CharField(column_name="x_contenant", constraints=[SQL("DEFAULT ''")])
-    bloque = BooleanField(column_name="x_bloque", constraints=[SQL("DEFAULT 0")])
+    magasin = CharField(
+        column_name="x_mag", max_length=3,
+        null=True, constraints=[SQL("DEFAULT ''")]
+    )
+    contenant = CharField(
+        column_name="x_contenant", max_length=20,
+        constraints=[SQL("DEFAULT ''")]
+    )
+    bloque = IntegerField(column_name="x_bloque", constraints=[SQL("DEFAULT 0")])
     stupefiant = BooleanField(
         column_name="x_stup", null=True, constraints=[SQL("DEFAULT 0")]
     )
@@ -165,13 +180,16 @@ class Adresse(BaseModel):
         column_name="x_nouv_qte_posage", null=True, constraints=[SQL("DEFAULT 0")]
     )
     emplacement = CharField(
-        column_name="x_emplacement", null=True, constraints=[SQL("DEFAULT ''")]
+        column_name="x_emplacement", max_length=20,
+        null=True, constraints=[SQL("DEFAULT ''")]
     )
     nouvel_emplacement = CharField(
-        column_name="x_nouv_emplacement", null=True, constraints=[SQL("DEFAULT ''")]
+        column_name="x_nouv_emplacement", max_length=20,
+        null=True, constraints=[SQL("DEFAULT ''")]
     )
     classe = CharField(
-        column_name="x_classe", null=True, constraints=[SQL("DEFAULT ''")]
+        column_name="x_classe", max_length=1,
+        null=True, constraints=[SQL("DEFAULT ''")]
     )
     dim_x = IntegerField(
         column_name="x_dim_x", null=True, constraints=[SQL("DEFAULT 0")]
@@ -185,7 +203,10 @@ class Adresse(BaseModel):
     adr_topo = CharField(
         column_name="x_adr_topo", null=True, constraints=[SQL("DEFAULT ''")]
     )
-    serial = CharField(column_name="x_serial", constraints=[SQL("DEFAULT ''")])
+    serial = CharField(
+        column_name="x_serial", max_length=20,
+        constraints=[SQL("DEFAULT ''")]
+    )
     nb_div = IntegerField(
         column_name="x_nb_div", null=True, constraints=[SQL("DEFAULT 0")]
     )
@@ -195,16 +216,50 @@ class Adresse(BaseModel):
     bloque_reappro = BooleanField(
         column_name="x_bloque_reappro", constraints=[SQL("DEFAULT 0")]
     )
+    bloque_message = CharField(
+        column_name="x_bloque_msg", max_length=100,
+        constraints=[SQL("DEFAULT ''")], default=''
+    )
+
+    def save(self, force_insert=False, only=None):
+        """Enforce control on each information passed"""
+        if not self.magasin:
+            self.magasin = self.adresse[:3]
+        if not self.etat:
+            self.etat = "L"
+        return super().save(force_insert, only)
 
     class Meta:
         table_name = "f_adr"
         indexes = (
-            (('x_adr',), True)
+            (('x_adr',), True),
+            (('x_mag',), False)
+        )
+
+
+class Reform(BaseModel):
+    pk = AutoField(column_name="x_pk", primary_key=True)
+    reference = CharField(
+        column_name="x_ref", max_length=35)
+    format = CharField(
+        column_name="x_format", max_length=10)
+    capacity = FloatField(
+        column_name='x_capa', constraints=[SQL("DEFAULT 0")], default=0)
+    nb_div = IntegerField(
+        column_name="x_nb_div", constraints=[SQL("DEFAULT 0")], default=0)
+    ordre = IntegerField(
+        column_name="x_ordre", constraints=[SQL("DEFAULT 0")], default=0)
+
+    class Meta:
+        table_name = "f_reform"
+        indexes = (
+            (('x_ref', 'x_format', 'x_nb_div'), True),
+            (('x_format',), False),
+            (('x_ref',), False),
         )
 
 
 class Compteur(BaseModel):
-
     pk = AutoField(
         column_name='x_pk', primary_key=True)
     cle = CharField(
@@ -223,7 +278,6 @@ class Compteur(BaseModel):
 
 
 class MagasinService(BaseModel):
-
     pk = AutoField(
         column_name='x_pk', primary_key=True)
     mag = CharField(
@@ -241,7 +295,6 @@ class MagasinService(BaseModel):
 
 
 class Zone(BaseModel):
-
     pk = AutoField(
         column_name='x_pk', primary_key=True)
     zone = CharField(
@@ -258,7 +311,6 @@ class Zone(BaseModel):
 
 
 class ZoneMag(BaseModel):
-
     pk = AutoField(
         column_name='x_pk', primary_key=True)
     zone = CharField(
@@ -273,3 +325,35 @@ class ZoneMag(BaseModel):
         indexes = (
             (('x_zone', 'x_mag'), True),
         )
+
+
+class EquipmentUnitStock(BaseModel):
+    pk = AutoField(column_name='x_pk', primary_key=True, index=True)
+    equipment_pk = IntegerField(column_name='x_equipment_pk', null=True, default=None, index=True)
+    total_line = IntegerField(column_name='x_total_line', constraints=[SQL("DEFAULT 0")], default=0)
+    total_colonne = IntegerField(column_name='x_total_colonne', constraints=[SQL("DEFAULT 0")], default=0)
+    order = IntegerField(column_name='x_order', constraints=[SQL("DEFAULT 0")], default=0)
+
+    class Meta:
+        table_name = 'f_equipment_unitstock'
+
+
+class EquipmentLines(BaseModel):
+    pk = AutoField(column_name='x_pk', primary_key=True, index=True)
+    unit_stock_pk = IntegerField(column_name='x_unit_stock_pk', null=True, default=None, index=True)
+    start_line = IntegerField(column_name='x_start_line', constraints=[SQL("DEFAULT 0")], default=0)
+    end_line = IntegerField(column_name='x_end_line', constraints=[SQL("DEFAULT 0")], default=0)
+
+    class Meta:
+        table_name = 'f_equipment_lines'
+
+
+class EquipmentColumns(BaseModel):
+    pk = AutoField(column_name='x_pk', primary_key=True, index=True)
+    line_pk = IntegerField(column_name='x_line_pk', null=True, default=None, index=True)
+    start_column = IntegerField(column_name='x_start_column', constraints=[SQL("DEFAULT 0")], default=0)
+    end_Column = IntegerField(column_name='x_end_Column', constraints=[SQL("DEFAULT 0")], default=0)
+    container_type = CharField(column_name='x_container_type', max_length=20, constraints=[SQL("DEFAULT ''")])
+
+    class Meta:
+        table_name = 'f_equipment_columns'
