@@ -225,7 +225,7 @@ class Seuil(BaseView):
         h.save()
 
         # Create f_gpao
-        if not gpao:
+        if not gpao == '1':
             g = Gpao(
                 chrono=datetime.datetime.now(),
                 poste='MEDIANWEB',
